translate.misc.optrecurse.ManPageOption

Package translate :: Package misc :: Module optrecurse :: Class ManPageOption |
[hide private]
[frames] | no frames]

# Class ManPageOption

source code

Instance Methods | [hide private]
take_action(self, action, dest, opt, value, values, parser) take_action that can handle manpage as well as standard actions | source code
Inherited from `optparse.Option`: `__init__`, `__repr__`, `__str__`, `check_value`, `convert_value`, `get_opt_string`, `process`, `takes_value` Inherited from `optparse.Option` (private): `_check_action`, `_check_callback`, `_check_choice`, `_check_const`, `_check_dest`, `_check_nargs`, `_check_opt_strings`, `_check_type`, `_set_attrs`, `_set_opt_strings` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| ACTIONS = ``(``'``store``'``,` `'``store_const``'``,` `'``store_true``'``,` `'``store_false``'``...``
Inherited from `optparse.Option`: `ALWAYS_TYPED_ACTIONS`, `ATTRS`, `CHECK_METHODS`, `CONST_ACTIONS`, `STORE_ACTIONS`, `TYPED_ACTIONS`, `TYPES`, `TYPE_CHECKER`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### take_action(self, action, dest, opt, value, values, parser) | source code
take_action that can handle manpage as well as standard actions Overrides: optparse.Option.take_action

Class Variable Details | [hide private]

  ### ACTIONS Value:
      ('store',
       'store_const',
       'store_true',
       'store_false',
       'append',
       'append_const',
       'count',
       'callback',
      ...